==> virtualenv-multiver-0.5.tar.gz: virtualenv-multiver-0.5/setup.py <==
#!/usr/bin/env python
#
# setup.py -- Installation for virtualenv-multiver
#
# Copyright (C) 2015 Beanbag, Inc.
#
# Permission is hereby granted, free of charge, to any person obtaining
# a copy of this software and associated documentation files (the
# 'Software'), to deal in the Software without restriction, including
# without limitation the rights to use, copy, modify, merge, publish,
# distribute, sublicense, and/or sell copies of the Software, and to
# permit persons to whom the Software is furnished to do so, subject to
# the following conditions:
#
# The above copyright notice and this permission notice shall be included
# in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED 'AS IS', WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
# CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
# TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

try:
    from setuptools import setup, find_packages
except ImportError:
    from ez_setup import use_setuptools
    use_setuptools()
    from setuptools import setup, find_packages

from virtualenv_multiver import get_package_version


PACKAGE_NAME = 'virtualenv-multiver'


setup(name=PACKAGE_NAME,
      version=get_package_version(),
      license='MIT',
      description='Python multi-version wrapper for virtualenv.',
      url='https://github.com/beanbaginc/virtualenv-multiver',
      maintainer='Christian Hammond',
      maintainer_email='christian@beanbaginc.com',
      packages=find_packages(),
      install_requires=['virtualenv'],
      entry_points={
          'console_scripts': [
              'virtualenv-multiver = virtualenv_multiver.main:main',
          ],
      },
      classifiers=[
          'Development Status :: 4 - Beta',
          'Environment :: Other Environment',
          'Intended Audience :: Developers',
          'License :: OSI Approved :: MIT License',
          'Operating System :: OS Independent',
          'Programming Language :: Python',
          'Topic :: Software Development',
          'Topic :: Software Development :: Testing',
      ]
)

==> virtualenv-multiver-1.0.tar.gz: virtualenv-multiver-1.0/setup.py <==
#!/usr/bin/env python
#
# setup.py -- Installation for virtualenv-multiver
#
# Copyright (C) 2015 Beanbag, Inc.
#
# Permission is hereby granted, free of charge, to any person obtaining
# a copy of this software and associated documentation files (the
# 'Software'), to deal in the Software without restriction, including
# without limitation the rights to use, copy, modify, merge, publish,
# distribute, sublicense, and/or sell copies of the Software, and to
# permit persons to whom the Software is furnished to do so, subject to
# the following conditions:
#
# The above copyright notice and this permission notice shall be included
# in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED 'AS IS', WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
# CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
# TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

from setuptools import setup, find_packages

from virtualenv_multiver import get_package_version


PACKAGE_NAME = 'virtualenv-multiver'


setup(name=PACKAGE_NAME,
      version=get_package_version(),
      license='MIT',
      description='Python multi-version wrapper for virtualenv.',
      url='https://github.com/beanbaginc/virtualenv-multiver',
      maintainer='Christian Hammond',
      maintainer_email='christian@beanbaginc.com',
      packages=find_packages(),
      install_requires=['virtualenv'],
      entry_points={
          'console_scripts': [
              'virtualenv-multiver = virtualenv_multiver.main:main',
          ],
      },
      classifiers=[
          'Development Status :: 5 - Production/Stable',
          'Environment :: Other Environment',
          'Intended Audience :: Developers',
          'License :: OSI Approved :: MIT License',
          'Operating System :: OS Independent',
          'Programming Language :: Python',
          'Programming Language :: Python :: 2',
          'Programming Language :: Python :: 2.7',
          'Programming Language :: Python :: 3',
          'Programming Language :: Python :: 3.6',
          'Programming Language :: Python :: 3.7',
          'Programming Language :: Python :: 3.8',
          'Topic :: Software Development',
          'Topic :: Software Development :: Testing',
      ]
)
